
FILE(GLOB LibLitmus_DIR "/home/gelliott/rtss12/liblitmus")

##====================================================
## Find LibLitmus libraries
##----------------------------------------------------
if(EXISTS "${LibLitmus_DIR}")

set(LIBLITMUS_LIB_COMPONENTS litmus)
find_path(LibLitmus_INCLUDE_DIR "litmus.h" PATHS "${LibLitmus_DIR}" PATH_SUFFIXES "include" DOC "")
if(EXISTS  ${LibLitmus_INCLUDE_DIR})
	include_directories(${LibLitmus_INCLUDE_DIR} "${LibLitmus_DIR}/arch/x86/include")
endif(EXISTS  ${LibLitmus_INCLUDE_DIR})

set(LITLIB_SUFFIX "")

## Initiate the variable before the loop
set(LibLitmus_LIBS "")
set(LibLitmus_FOUND_TMP true)

## Loop over each components
foreach(__LITLIB ${LIBLITMUS_LIB_COMPONENTS})
	find_library(LibLitmus_${__LITLIB}_LIBRARY_DEBUG NAMES "${__LITLIB}${LITLIB_SUFFIX}d" "lib${__LITLIB}${LITLIB_SUFFIX}d" PATHS "${LibLitmus_DIR}" NO_DEFAULT_PATH)
    find_library(LibLitmus_${__LITLIB}_LIBRARY_RELEASE NAMES "${__LITLIB}${LITLIB_SUFFIX}" "lib${__LITLIB}${LITLIB_SUFFIX}" PATHS "${LibLitmus_DIR}" NO_DEFAULT_PATH)

    #Remove the cache value
    set(LibLitmus_${__LITLIB}_LIBRARY "" CACHE STRING "" FORCE)

    #both debug/release
    if(LibLitmus_${__LITLIB}_LIBRARY_DEBUG AND LibLitmus_${__LITLIB}_LIBRARY_RELEASE)
    	set(LibLitmus_${__LITLIB}_LIBRARY debug ${LibLitmus_${__LITLIB}_LIBRARY_DEBUG} optimized ${LibLitmus_${__LITLIB}_LIBRARY_RELEASE}  CACHE STRING "" FORCE)
    #only debug
    elseif(LibLitmus_${__LITLIB}_LIBRARY_DEBUG)
    	set(LibLitmus_${__LITLIB}_LIBRARY ${LibLitmus_${__LITLIB}_LIBRARY_DEBUG}  CACHE STRING "" FORCE)
   	#only release
    elseif(LibLitmus_${__LITLIB}_LIBRARY_RELEASE)
    	set(LibLitmus_${__LITLIB}_LIBRARY ${LibLitmus_${__LITLIB}_LIBRARY_RELEASE}  CACHE STRING "" FORCE)
    #no library found
    else()
    	set(LibLitmus_FOUND_TMP false)
    endif()

    #Add to the general list
    if(LibLitmus_${__LITLIB}_LIBRARY)
    	set(LibLitmus_LIBS ${LibLitmus_LIBS} ${LibLitmus_${__LITLIB}_LIBRARY})
    endif(LibLitmus_${__LITLIB}_LIBRARY)
endforeach(__LITLIB)

set(LibLitmus_FOUND ${LibLitmus_FOUND_TMP} CACHE BOOL "" FORCE)

else(EXISTS "${LibLitmus_DIR}")
	set(ERR_MSG "Please specify LibLitmus directory using LibLitmus_DIR env. variable")
endif(EXISTS "${LibLitmus_DIR}")
##====================================================


##====================================================
## Print message
##----------------------------------------------------
if(NOT LibLitmus_FOUND)
  # make FIND_PACKAGE friendly
  if(NOT LibLitmus_FIND_QUIETLY)
        if(LibLitmus_FIND_REQUIRED)
          message(FATAL_ERROR "LibLitmus required but some headers or libs not found. ${ERR_MSG}")
        else(LibLitmus_FIND_REQUIRED)
          message(STATUS "WARNING: LibLitmus was not found. ${ERR_MSG}")
        endif(LibLitmus_FIND_REQUIRED)
  endif(NOT LibLitmus_FIND_QUIETLY)
endif(NOT LibLitmus_FOUND)
##====================================================


##====================================================
## Backward compatibility
##----------------------------------------------------
if(LibLitmus_FOUND)
option(LibLitmus_BACKWARD_COMPA "Add some variable to make this script compatible with the other version of FindLibLitmus.cmake" false)
if(LibLitmus_BACKWARD_COMPA)
        find_path(LibLitmus_INCLUDE_DIRS "litmus.h" PATHS "${LibLitmus_DIR}" PATH_SUFFIXES "include" DOC "Include directory")
        find_path(LibLitmus_INCLUDE_DIR "litmus.h" PATHS "${LibLitmus_DIR}" PATH_SUFFIXES "include" DOC "Include directory")
        set(LibLitmus_LIBRARIES "${LibLitmus_LIBS}" CACHE STRING "" FORCE)
endif(LibLitmus_BACKWARD_COMPA)
endif(LibLitmus_FOUND)
##====================================================
