
FILE(GLOB LibSegvCatch_DIR "/usr/local/lib")

##====================================================
## Find LibSegvCatch libraries
##----------------------------------------------------
if(EXISTS "${LibSegvCatch_DIR}")

set(LIBSEGVCATCH_LIB_COMPONENTS segvcatch)
find_path(LibSegvCatch_INCLUDE_DIR "segvcatch.h" PATHS "${LibSegvCatch_DIR}" PATH_SUFFIXES "include" DOC "")
if(EXISTS  ${LibSegvCatch_INCLUDE_DIR})
	include_directories(${LibSegvCatch_INCLUDE_DIR})
endif(EXISTS  ${LibSegvCatch_INCLUDE_DIR})

set(LITLIB_SUFFIX "")

## Initiate the variable before the loop
set(LibSegvCatch_LIBS "")
set(LibSegvCatch_FOUND_TMP true)

## Loop over each components
foreach(__SEGVLIB ${LIBSEGVCATCH_LIB_COMPONENTS})
	find_library(LibSegvCatch_${__SEGVLIB}_LIBRARY_DEBUG NAMES "${__SEGVLIB}${LITLIB_SUFFIX}d" "lib${__SEGVLIB}${LITLIB_SUFFIX}d" PATHS "${LibSegvCatch_DIR}" NO_DEFAULT_PATH)
    find_library(LibSegvCatch_${__SEGVLIB}_LIBRARY_RELEASE NAMES "${__SEGVLIB}${LITLIB_SUFFIX}" "lib${__SEGVLIB}${LITLIB_SUFFIX}" PATHS "${LibSegvCatch_DIR}" NO_DEFAULT_PATH)

    #Remove the cache value
    set(LibSegvCatch_${__SEGVLIB}_LIBRARY "" CACHE STRING "" FORCE)

    #both debug/release
    if(LibSegvCatch_${__SEGVLIB}_LIBRARY_DEBUG AND LibSegvCatch_${__SEGVLIB}_LIBRARY_RELEASE)
    	set(LibSegvCatch_${__SEGVLIB}_LIBRARY debug ${LibSegvCatch_${__SEGVLIB}_LIBRARY_DEBUG} optimized ${LibSegvCatch_${__SEGVLIB}_LIBRARY_RELEASE}  CACHE STRING "" FORCE)
    #only debug
    elseif(LibSegvCatch_${__SEGVLIB}_LIBRARY_DEBUG)
    	set(LibSegvCatch_${__SEGVLIB}_LIBRARY ${LibSegvCatch_${__SEGVLIB}_LIBRARY_DEBUG}  CACHE STRING "" FORCE)
   	#only release
    elseif(LibSegvCatch_${__SEGVLIB}_LIBRARY_RELEASE)
    	set(LibSegvCatch_${__SEGVLIB}_LIBRARY ${LibSegvCatch_${__SEGVLIB}_LIBRARY_RELEASE}  CACHE STRING "" FORCE)
    #no library found
    else()
    	set(LibSegvCatch_FOUND_TMP false)
    endif()

    #Add to the general list
    if(LibSegvCatch_${__SEGVLIB}_LIBRARY)
    	set(LibSegvCatch_LIBS ${LibSegvCatch_LIBS} ${LibSegvCatch_${__SEGVLIB}_LIBRARY})
    endif(LibSegvCatch_${__SEGVLIB}_LIBRARY)
endforeach(__SEGVLIB)

set(LibSegvCatch_FOUND ${LibSegvCatch_FOUND_TMP} CACHE BOOL "" FORCE)

else(EXISTS "${LibSegvCatch_DIR}")
	set(ERR_MSG "Please specify LibSegvCatch directory using LibSegvCatch_DIR env. variable")
endif(EXISTS "${LibSegvCatch_DIR}")
##====================================================


##====================================================
## Print message
##----------------------------------------------------
if(NOT LibSegvCatch_FOUND)
  # make FIND_PACKAGE friendly
  if(NOT LibSegvCatch_FIND_QUIETLY)
        if(LibSegvCatch_FIND_REQUIRED)
          message(FATAL_ERROR "LibSegvCatch required but some headers or libs not found. ${ERR_MSG}")
        else(LibSegvCatch_FIND_REQUIRED)
          message(STATUS "WARNING: LibSegvCatch was not found. ${ERR_MSG}")
        endif(LibSegvCatch_FIND_REQUIRED)
  endif(NOT LibSegvCatch_FIND_QUIETLY)
endif(NOT LibSegvCatch_FOUND)
##====================================================


##====================================================
## Backward compatibility
##----------------------------------------------------
if(LibSegvCatch_FOUND)
option(LibSegvCatch_BACKWARD_COMPA "Add some variable to make this script compatible with the other version of FindLibSegvCatch.cmake" false)
if(LibSegvCatch_BACKWARD_COMPA)
        find_path(LibSegvCatch_INCLUDE_DIRS "segvcatch.h" PATHS "${LibSegvCatch_DIR}" PATH_SUFFIXES "include" DOC "Include directory")
        find_path(LibSegvCatch_INCLUDE_DIR "segvcatch.h" PATHS "${LibSegvCatch_DIR}" PATH_SUFFIXES "include" DOC "Include directory")
        set(LibSegvCatch_LIBRARIES "${LibSegvCatch_LIBS}" CACHE STRING "" FORCE)
endif(LibSegvCatch_BACKWARD_COMPA)
endif(LibSegvCatch_FOUND)
##====================================================
